@@ -75,6 +75,10 @@ function pushSelectedOptions(select, items) {
     }
 }
 
+function unblock(form) {
+    form.removeAttribute('block-submissions');
+}
+
 function jsform_submit(form) {
     /*
         By default, we don't allow duplicate form submissions.
@@ -107,7 +111,8 @@ function jsform_submit(form) {
         if (method != 'get') return action
         // Now we need to serialize form
         // Ideally, we'd use FormData just like get_body, and pass to URLSearchParams to serialize, but that's not supported in IE, so we have to serialize ourselves
-        return action.split('?')[0] + '?' + to_querystring(form, submitting_button);
+        // Note - be sure to trim off any existing querystring or hash from the action
+        return action.split(/[#?]/)[0] + '?' + to_querystring(form, submitting_button);
     }
     function get_body() {
         if (method == 'get') return null
@@ -139,6 +144,9 @@ function jsform_submit(form) {
         form_clone.dispatchEvent.call(form, (e));
         if (!e.defaultPrevented) {
             alert('Failed to submit form: network error.');
+            // Unblock the form, IFF it's a get request
+            // We assume POST may alter data on server, and user must explicitly unblock the form if they want to allow further submissions
+            if (method == 'get') unblock(form);
         }
     }
     r.onload = function(event) {
@@ -157,6 +165,9 @@ function jsform_submit(form) {
             form_clone.dispatchEvent.call(form, (e));
             if (!e.defaultPrevented) {
                 alert('Submission complete: '+r.status+' '+r.statusText);
+                // Unblock the form, IFF it's a get request
+                // We assume POST may alter data on server, and user must explicitly unblock the form if they want to allow further submissions
+                if (method == 'get') unblock(form);
             }
         }
         else {
@@ -168,6 +179,7 @@ function jsform_submit(form) {
             form_clone.dispatchEvent.call(form, (e));
             if (!e.defaultPrevented) {
                 alert('Submission error: '+r.status+' '+r.statusText);
+                unblock(form);
             }
         }
     }
